Structs
- Croissant
- Croissant is a simple task scheduler It can run a task at a specific time or at a specific interval It can run a task in sync or async It is a wrapper around the Ticker struct It is not a cron scheduler, it is a simple scheduler
Attribute Macros
- croissant
- Creates a wrapper function, that can be Boxed and passed to Croissant scheduler